summaryrefslogtreecommitdiff
path: root/lisp/language/ethiopic.el
diff options
context:
space:
mode:
Diffstat (limited to 'lisp/language/ethiopic.el')
-rw-r--r--lisp/language/ethiopic.el45
1 files changed, 25 insertions, 20 deletions
diff --git a/lisp/language/ethiopic.el b/lisp/language/ethiopic.el
index 7857289ac47..6fce966939e 100644
--- a/lisp/language/ethiopic.el
+++ b/lisp/language/ethiopic.el
@@ -1,9 +1,12 @@
;;; ethiopic.el --- support for Ethiopic -*- coding: iso-2022-7bit; -*-
;; Copyright (C) 1997 Free Software Foundation, Inc.
;; Copyright (C) 1995, 2001
;; National Institute of Advanced Industrial Science and Technology (AIST)
;; Registration Number H14PRO021
+;; Copyright (C) 2005
+;; National Institute of Advanced Industrial Science and Technology (AIST)
+;; Registration Number: H15PRO 110
;; Keywords: multilingual, Ethiopic
@@ -56,30 +59,32 @@
"Ethiopic" '((setup-function . setup-ethiopic-environment-internal)
(exit-function . exit-ethiopic-environment)
(charset ethiopic)
- (coding-system iso-2022-7bit)
- (coding-priority iso-2022-7bit)
+ (coding-system utf-8-emacs)
+ (coding-priority utf-8-emacs)
(input-method . "ethiopic")
(features ethio-util)
- (sample-text . "$(3$Q#U!.(B")
+ (sample-text . "ፊደል")
(documentation .
-"This language envrironment provides these function key bindings
- \(old bindings are shown in parentheses):
- [f3] ethio-fidel-to-sera-buffer (f5)
- [S-f3] ethio-fidel-to-sera-region (f5)
- [C-f3] ethio-fidel-to-sera-mail-or-marker (f5)
-
- [f4] ethio-sera-to-fidel-buffer (unchanged)
- [S-f4] ethio-sera-to-fidel-region (unchanged)
- [C-f4] ethio-sera-to-fidel-mail-or-marker (unchanged)
-
- [S-f5] ethio-toggle-punctuation (f3)
- [S-f6] ethio-modify-vowel (f6)
- [S-f7] ethio-replace-space (f7)
- [S-f8] ethio-input-special-character (f8)
- [S-f9] ethio-replace-space (unchanged)
- [C-f9] ethio-toggle-space (f2)"
+"This language envrironment provides these function key bindings:
+ [f3] ethio-fidel-to-sera-buffer
+ [S-f3] ethio-fidel-to-sera-region
+ [C-f3] ethio-fidel-to-sera-marker
+
+ [f4] ethio-sera-to-fidel-buffer
+ [S-f4] ethio-sera-to-fidel-region
+ [C-f4] ethio-sera-to-fidel-marker
+
+ [S-f5] ethio-toggle-punctuation
+ [S-f6] ethio-modify-vowel
+ [S-f7] ethio-replace-space
+
+ [S-f9] ethio-replace-space
+ [C-f9] ethio-toggle-space"
)))
+;; For automatic composition
+(aset composition-function-table ? 'ethio-composition-function)
+
(provide 'ethiopic)
;;; arch-tag: e81329d9-1286-43ba-92fd-54ce5c7b213c
@@ -1,9 +1,12 @@
-;;; ethiopic.el --- support for Ethiopic -*- coding: iso-2022-7bit; -*-
+;;; ethiopic.el --- support for Ethiopic -*- coding: utf-8-emacs; -*-
;; Copyright (C) 1997 Free Software Foundation, Inc.
;; Copyright (C) 1995, 2001